@@ -17,7 +17,7 @@ from .util import (
     value_to_xml_text,
     xml_text_to_value,
 )
-from .version import EXCHANGE_2013, Build, SupportedVersionInstanceMixIn
+from .version import EXCHANGE_2013, SupportedVersionInstanceMixIn
 
 log = logging.getLogger(__name__)
 
@@ -423,10 +423,6 @@ class BooleanField(FieldURIField):
     value_cls = bool
 
 
-class OnOffField(BooleanField):
-    """A field that handles boolean values that are On/Off instead of True/False."""
-
-
 class IntegerField(FieldURIField):
     """A field that handles integer values."""
 
@@ -1479,6 +1475,9 @@ class PermissionSetField(EWSElementField):
         kwargs["value_cls"] = PermissionSet
         super().__init__(*args, **kwargs)
 
+    def to_xml(self, value, version):
+        return value.to_xml(version=version)
+
 
 class EffectiveRightsField(EWSElementField):
     def __init__(self, *args, **kwargs):
@@ -1488,33 +1487,6 @@ class EffectiveRightsField(EWSElementField):
         super().__init__(*args, **kwargs)
 
 
-class BuildField(CharField):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.value_cls = Build
-
-    def from_xml(self, elem, account):
-        val = self._get_val_from_elem(elem)
-        if val:
-            try:
-                return self.value_cls.from_hex_string(val)
-            except (TypeError, ValueError):
-                log.warning("Invalid server version string: %r", val)
-        return val
-
-
-class ProtocolListField(EWSElementListField):
-    # There is not containing element for this field. Just multiple 'Protocol' elements on the 'Account' element.
-    def __init__(self, *args, **kwargs):
-        from .autodiscover.properties import Protocol
-
-        kwargs["value_cls"] = Protocol
-        super().__init__(*args, **kwargs)
-
-    def from_xml(self, elem, account):
-        return [self.value_cls.from_xml(elem=e, account=account) for e in elem.findall(self.value_cls.response_tag())]
-
-
 class RoutingTypeField(ChoiceField):
     def __init__(self, *args, **kwargs):
         kwargs["choices"] = {Choice("SMTP"), Choice("EX")}
