@@ -38,7 +38,7 @@ from ..errors import (
     SOAPError,
     TransportError,
 )
-from ..folders import BaseFolder, Folder, RootOfHierarchy
+from ..folders import ArchiveRoot, BaseFolder, Folder, PublicFoldersRoot, Root, RootOfHierarchy
 from ..items import BaseItem
 from ..properties import (
     BaseItemId,
@@ -927,10 +927,7 @@ def to_item_id(item, item_cls):
         # Allow any BaseItemId subclass to pass unaltered
         return item
     if isinstance(item, (BaseFolder, BaseItem)):
-        try:
-            return item.to_id()
-        except ValueError:
-            return item
+        return item.to_id()
     if isinstance(item, (str, tuple, list)):
         return item_cls(*item)
     return item_cls(item.id, item.changekey)
@@ -978,20 +975,24 @@ def parse_folder_elem(elem, folder, account):
         f = folder.from_xml(elem=elem, account=folder.account)
     elif isinstance(folder, Folder):
         f = folder.from_xml_with_root(elem=elem, root=folder.root)
+        f._distinguished_id = folder._distinguished_id
     elif isinstance(folder, DistinguishedFolderId):
-        # We don't know the root, so assume account.root.
-        for cls in account.root.WELLKNOWN_FOLDERS:
+        # We don't know the root or even account, but we need to attach the folder to something if we want to make
+        # future requests with this folder. Use 'account' but make sure to always use the distinguished folder ID going
+        # forward, instead of referencing anything connected to 'account'.
+        roots = (Root, ArchiveRoot, PublicFoldersRoot)
+        for cls in roots + tuple(chain(*(r.WELLKNOWN_FOLDERS for r in roots))):
             if cls.DISTINGUISHED_FOLDER_ID == folder.id:
                 folder_cls = cls
                 break
         else:
             raise ValueError(f"Unknown distinguished folder ID: {folder.id}")
-        f = folder_cls.from_xml_with_root(elem=elem, root=account.root)
+        if folder_cls in roots:
+            f = folder_cls.from_xml(elem=elem, account=account)
+        else:
+            f = folder_cls.from_xml_with_root(elem=elem, root=account.root)
+        f._distinguished_id = folder
     else:
         # 'folder' is a generic FolderId instance. We don't know the root so assume account.root.
         f = Folder.from_xml_with_root(elem=elem, root=account.root)
-    if isinstance(folder, DistinguishedFolderId):
-        f.is_distinguished = True
-    elif isinstance(folder, BaseFolder) and folder.is_distinguished:
-        f.is_distinguished = True
     return f
