@@ -1,5 +1,5 @@
-from .common import EWSAccountService
 from ..util import create_element, set_xml_value
+from .common import EWSAccountService
 
 
 class DeleteUserConfiguration(EWSAccountService):
@@ -7,13 +7,13 @@ class DeleteUserConfiguration(EWSAccountService):
     https://docs.microsoft.com/en-us/exchange/client-developer/web-service-reference/deleteuserconfiguration-operation
     """
 
-    SERVICE_NAME = 'DeleteUserConfiguration'
+    SERVICE_NAME = "DeleteUserConfiguration"
     returns_elements = False
 
     def call(self, user_configuration_name):
         return self._get_elements(payload=self.get_payload(user_configuration_name=user_configuration_name))
 
     def get_payload(self, user_configuration_name):
-        deleteuserconfiguration = create_element('m:%s' % self.SERVICE_NAME)
-        set_xml_value(deleteuserconfiguration, user_configuration_name, version=self.account.version)
-        return deleteuserconfiguration
+        return set_xml_value(
+            create_element(f"m:{self.SERVICE_NAME}"), user_configuration_name, version=self.account.version
+        )
