@@ -858,11 +858,14 @@ EWS auth: NTLM""",
             ).clean(version=None)
 
     def test_convert_id(self):
-        i = self.account.root.id
+        ews_id = (
+            "AAMkADIxNDdkMTI4LTMxNTgtNGYzYy1iMGFlLWQxOTIzYTVlNTAwMgAuAAAAAAC"
+            "QxfuhknwST6zPr7QuwK7BAQDtzmFCgwmzTq/6+pzfxPNiAAAAAAEBAAA="
+        )
         for fmt in ID_FORMATS:
             res = list(
                 self.account.protocol.convert_ids(
-                    [AlternateId(id=i, format=EWS_ID, mailbox=self.account.primary_smtp_address)],
+                    [AlternateId(id=ews_id, format=EWS_ID, mailbox=self.account.primary_smtp_address)],
                     destination_format=fmt,
                 )
             )
@@ -871,7 +874,8 @@ EWS auth: NTLM""",
         # Test bad format
         with self.assertRaises(ValueError) as e:
             self.account.protocol.convert_ids(
-                [AlternateId(id=i, format=EWS_ID, mailbox=self.account.primary_smtp_address)], destination_format="XXX"
+                [AlternateId(id=ews_id, format=EWS_ID, mailbox=self.account.primary_smtp_address)],
+                destination_format="XXX",
             )
         self.assertEqual(e.exception.args[0], f"'destination_format' 'XXX' must be one of {sorted(ID_FORMATS)}")
         # Test bad item type
@@ -1058,6 +1062,7 @@ r5p9FrBgavAw5bKO54C0oQKpN/5fta5l6Ws0
         with self.assertRaises(RateLimitError) as e:
             _ = self.get_test_protocol(auth_type=None, retry_policy=FaultTolerance(max_wait=0.5)).auth_type
         self.assertEqual(e.exception.args[0], "Max timeout reached")
+        self.assertEqual(str(e.exception), "Max timeout reached (gave up when asked to back off 10.000 seconds)")
 
     @patch("requests.sessions.Session.post", return_value=DummyResponse(status_code=401))
     def test_get_service_authtype_401(self, m):
